import {
  Button,
  Flex,
  Input,
  message,
  Popconfirm,
  Space,
  Table,
  Tag,
} from "antd";
import Column from "antd/es/table/Column";
import { useEffect, useState } from "react";
import { useSelector } from "react-redux";
import axiosInstance from "../../api/axios";
import { deviceStatusOptions } from "../../config/DeviceStatusConfig";
import { selectUserId } from "../../features/auth/authSlice";
import DeviceDetailModal from "./DeviceDetailModal";

export default function DeviceManage() {
  const [devices, setDevices] = useState([]);
  const [selectedDevice, setSelectedDevice] = useState(null);
  const [modalOpen, setModalOpen] = useState(false);
  const [modalMode, setModalMode] = useState(null);
  const [searchName, setSearchName] = useState(null);
  const [pagination, setPagination] = useState({
    current: 1,
    pageSize: 10,
    total: 0,
  });

  const userId = useSelector(selectUserId);
  const fetchData = async (pagination, name = searchName) => {
    const data = await axiosInstance.get(`/device/${userId}`, {
      params: {
        page: pagination.current,
        size: pagination.pageSize,
        name,
      },
    });

    setDevices(data.records);
    setPagination({
      ...pagination,
      total: data.total,
    });
  };

  useEffect(() => {
    fetchData(pagination);
  }, []);

  const handlePageChange = async (pagination) => {
    await fetchData(pagination);
  };

  const handleDelete = async (deviceId) => {
    await axiosInstance.delete(`/device/${deviceId}`);
    message.success("删除成功");
    const newPagination = {
      ...pagination,
      current: 1,
    };
    setPagination(newPagination);
    await fetchData(newPagination);
  };

  const handleSearch = async (value) => {
    setSearchName(value);
    const newPagination = {
      ...pagination,
      current: 1,
    };
    setPagination(newPagination);
    await fetchData(newPagination, value);
  };

  // 名称、使用要求、位置、状态
  return (
    <>
      <Flex justify="space-between">
        <Input.Search
          placeholder="请输入设备名称"
          onSearch={handleSearch}
          style={{ width: "200px" }}
          className="m-4"
        />
        <Button
          className="m-4"
          type="primary"
          onClick={() => {
            setModalMode("create");
            setSelectedDevice(null);
            setModalOpen(true);
          }}
        >
          添加设备
        </Button>
      </Flex>

      <Table
        rowKey="deviceId"
        dataSource={devices}
        onChange={handlePageChange}
        pagination={pagination}
      >
        <Column title="名称" key="name" dataIndex="name" />
        <Column
          title="使用要求"
          key="usageRequirement"
          dataIndex="usageRequirement"
          ellipsis={true}
        />
        <Column title="位置" key="location" dataIndex="location" />
        <Column
          title="状态"
          key="status"
          render={(_, { status }) => {
            const color = status === "AVAILABLE" ? "green" : "grey";
            const option = deviceStatusOptions.find(
              (item) => item.value === status
            );
            return (
              <Tag color={color} key="status">
                {option ? option.label : status}
              </Tag>
            );
          }}
        />
        <Column
          title="操作"
          render={(_, record) => {
            return (
              <Space>
                <Button
                  size="small"
                  onClick={() => {
                    setSelectedDevice(record);
                    setModalOpen(true);
                    setModalMode("edit");
                  }}
                >
                  编辑
                </Button>
                <Popconfirm
                  title="删除设备"
                  description="确认要删除该设备吗？"
                  onConfirm={() => handleDelete(record.deviceId)}
                >
                  <Button color="red" variant="solid" size="small">
                    删除
                  </Button>
                </Popconfirm>
              </Space>
            );
          }}
        />
      </Table>
      <DeviceDetailModal
        visiable={modalOpen}
        device={selectedDevice}
        mode={modalMode}
        onclose={() => {
          setModalOpen(false);
          setSelectedDevice(null);
        }}
        onSuccess={async () => {
          await fetchData({
            ...pagination,
            current: 1,
          });
        }}
      />
    </>
  );
}
